==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/my_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_menu'] = 						"menu";
$lang['section_action'] = 						"do";
$lang['section_search'] = 						"search";
$lang['section_update'] = 						"update";
$lang['section_publishing'] =					"publishing";
$lang['section_comments'] = 					"comments";


//MENU
$lang['menu_membership'] = 						"membership";
$lang['menu_profile'] = 						"profiles";
$lang['menu_edit_profile'] = 					"edit profile";
$lang['menu_bookmarks'] = 						"marks and tips";
$lang['menu_blog'] =							"blog";
$lang['menu_overview'] = 						"overview";
$lang['menu_library'] = 						"library";
$lang['menu_publishing'] = 						"publishing";
$lang['menu_files'] = 							"files and pictures";
$lang['menu_shout'] = 							"shout!";


//HEADER
$lang['hdr_image'] = 							"photo album";
$lang['hdr_search_results'] = 					"search results";


//A HREF TAGS (links)
$lang['href_add'] = 							"add";
$lang['href_edit_this'] = 						"edit this";
$lang['href_list'] = 							"list";


//ERRORS
$lang['err_no_events'] = 						"Sorry, you have no events available.";
$lang['err_no_library'] = 						"Sorry, no library available.";
$lang['err_no_search_results'] = 				"Sorry, nothing found. Please try another search.";
$lang['err_no_polls'] = 						"Sorry, you have no polls available.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_statistics'] = 					"Sorry, there are no statistics available.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";
$lang['sub_homepage'] = 						"my home";
$lang['sub_edit'] = 							"edit";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";
$lang['sub_search'] = 							"search";


//BODY TEXT
$lang['txt_library'] = 							"library";//breadcrumb
$lang['err_no_image'] = 						"I have no image;)";
$lang['txt_votes'] = 							"votes";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_from'] =								"From";
$lang['txt_author'] = 							"author";
$lang['txt_hometown'] = 						"hometown";
$lang['txt_last_edit'] = 						"last edit by";
$lang['txt_joined'] = 							"joined";
$lang['txt_comment_no_delete'] = 				"You cannot delete this item as it has comments against it.";

?>

==> aroundme_0_4_2.zip: aroundme_0_4_2/www/aroundme_0_4_2/language/1/am_default/my_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_menu'] = 						"menu";
$lang['section_action'] = 						"do";
$lang['section_search'] = 						"search";
$lang['section_update'] = 						"update";
$lang['section_publishing'] =					"publishing";
$lang['section_comments'] = 					"comments";


//MENU
$lang['menu_membership'] = 						"membership";
$lang['menu_profile'] = 						"profiles";
$lang['menu_edit_profile'] = 					"edit profile";
$lang['menu_bookmarks'] = 						"marks and tips";
$lang['menu_blog'] =							"blog";
$lang['menu_overview'] = 						"overview";
$lang['menu_library'] = 						"library";
$lang['menu_publishing'] = 						"publishing";
$lang['menu_files'] = 							"files and pictures";
$lang['menu_shout'] = 							"shout!";


//HEADER
$lang['hdr_image'] = 							"photo album";
$lang['hdr_search_results'] = 					"search results";


//A HREF TAGS (links)
$lang['href_add'] = 							"add";
$lang['href_edit_this'] = 						"edit this";
$lang['href_list'] = 							"list";


//IMAGE TITLES
$lang['ttl_send_message'] = 					"send message";


//ERRORS
$lang['err_no_events'] = 						"Sorry, you have no events available.";
$lang['err_no_library'] = 						"Sorry, no library available.";
$lang['err_no_search_results'] = 				"Sorry, nothing found. Please try another search.";
$lang['err_no_polls'] = 						"Sorry, you have no polls available.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_statistics'] = 					"Sorry, there are no statistics available.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";
$lang['sub_homepage'] = 						"my home";
$lang['sub_edit'] = 							"edit";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";
$lang['sub_search'] = 							"search";


//BODY TEXT
$lang['txt_library'] = 							"library";//breadcrumb
$lang['err_no_image'] = 						"I have no image;)";
$lang['txt_votes'] = 							"votes";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_from'] =								"From";
$lang['txt_author'] = 							"author";
$lang['txt_hometown'] = 						"hometown";
$lang['txt_last_edit'] = 						"last edit by";
$lang['txt_joined'] = 							"joined";
$lang['txt_comment_no_delete'] = 				"You cannot delete this item as it has comments against it.";
$lang['txt_wiki_default'] = 					"LibraryFirstPage"; //must be WIKI formatted LikeThisExample

?>
